==> hoteldruid-mod-ca_2.1.3-1.tar.gz: ca/disponibilita.php <==
<?php

switch ($messaggio) {

case "Le date sono sbagliate":  		$messaggio = "Les dates són errònies"; break;
case "persone":  				$messaggio = "persones"; break;
case "La settimana dal":  			$messaggio = "La setmana des del"; break;
case "Il giorno dal":  				$messaggio = "El dia des del"; break;
case "al":  					$messaggio = "fins el"; break;
case "è piena":  				$messaggio = "és plena"; break;
case "è pieno":  				$messaggio = "és ple"; break;
case "<b>C'è</b> ancora disponibilità nel periodo richiesto":	$messaggio = "Encara <b>hi ha</b> disponibilitat pel període demanat"; break;
case ", ma si dovranno fare degli spostamenti nei periodi della <div style=\"display: inline; color: blue;\">regola di assegnazione 1</div>":	$messaggio = ", perà caldrà fer alguns movimients als períodes de la <div style=\"display: inline; color: blue;\">regla d'assignació 1</div>"; break;
case "<b>Non c'è</b> più disponibilità nel periodo richiesto":	$messaggio = "<b>No hi ha</b> disponibilitat al període demanat"; break;
case "Si potrebbe inserire la prenotazione dividendola in":	$messaggio = "Se podria inserir la reserva dividint-la en"; break;
case "parti":  					$messaggio = "trams"; break;
case "Periodo di":  				$messaggio = "Període de"; break;
case "dal":  					$messaggio = "des del"; break;
case "settimane":  				$messaggio = "setmanes"; break;
case "giorni":  				$messaggio = "dies"; break;
case "Tariffa":  				$messaggio = "Tarifa"; break;
case "compresi":  				$messaggio = "inclosos"; break;
case "di costi aggiuntivi fissi":  		$messaggio = "de suplements fixes"; break;
case "Ricontrolla":  				$messaggio = "Torna a cercar"; break;
case "Torna al menù principale":  		$messaggio = "Torna al menú principal"; break;
case "documento di tipo":  			$messaggio = "document tipus"; break;
case "visualizza":  				$messaggio = "Veure"; break;
case "con la tariffa":  			$messaggio = "amb la tarifa"; break;
case "Inserisci la prenotazione":  		$messaggio = "Insereix la reserva"; break;
case "settimana":  				$messaggio = "setmana"; break;
case "giorno":  				$messaggio = "dia"; break;
case "Non c'è nussun periodo delle regole 1 in cui sia consentito inserire prenotazioni per l'utente":	$messaggio = "No hi ha cap període de les regles 1 al qual s'hi permeti inserir reserves a l'usuari"; break;
case "costo aggiuntivo unico":  		$messaggio = "suplement puntual"; break;
case "costo aggiuntivo settimanale":  		$messaggio = "suplement setmanal"; break;
case "costo aggiuntivo giornaliero":  		$messaggio = "suplement diari"; break;
case "nº di settimane da applicare":  		$messaggio = "nº de setmanes a aplicar"; break;
case "nº di giorni da applicare":  		$messaggio = "nº de dies a aplicar"; break;
case "di costi aggiuntivi":  			$messaggio = "de suplements"; break;
case "Aggiungi":  				$messaggio = "Afegir"; break;
case "da moltiplicare per":  			$messaggio = "a multiplicar per"; break;
case "Non si sono potuti applicare alla tariffa uno o più costi":	$messaggio = "No s'han pogut aplicar un o més costos a la tarifa"; break;
case "Scegliere le settimane in cui applicare il costo aggiuntivo":	$messaggio = "Escollir les setmanes a les quals s'aplicarà el suplement"; break;
case "Continua":  				$messaggio = "Continua"; break;
case "tariffa":  				$messaggio = "tarifa"; break;
case "Quadro indicativo disponibilità":  	$messaggio = "Quadre de disponibilitat"; break;
case "potrebbe non essere preciso":  		$messaggio = "podria no ser exacte"; break;
case "persona":  				$messaggio = "persona"; break;
case "Caparra":  				$messaggio = "Arres"; break;
case "con i costi aggiuntivi selezionati":  	$messaggio = "amb els suplements seleccionats"; break;
case "per":  					$messaggio = "per"; break;
case "Commissioni":  				$messaggio = "Comissions"; break;
case "Non c'è nessuna tariffa disponibile in questo periodo":	$messaggio = "No hi ha cap tarifa disponible a aquest període"; break;
case "Mostra le tariffe non disponibili":  	$messaggio = "Mostrar tarifes no disponibles"; break;
case "Scegliere le settimane in cui applicare il costo aggiuntivo":	$messaggio = "Escollir les semanes a les quals s'aplicarà el suplement"; break;
case "Scegliere i giorni in cui applicare il costo aggiuntivo":	$messaggio = "Escollir els dies als quals s'aplicarà el suplement"; break;
case "costo aggiuntivo":  			$messaggio = "suplement"; break;
case "TOTALE":  				$messaggio = "TOTAL"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-ca_3.0.8-1.tar.gz: ca/disponibilita.php <==
<?php

switch ($messaggio) {

case "Le date sono sbagliate":  		$messaggio = "Les dates són errònies"; break;
case "persone":  				$messaggio = "persones"; break;
case "La settimana dal":  			$messaggio = "La setmana des del"; break;
case "Il giorno dal":  				$messaggio = "El dia des del"; break;
case "al":  					$messaggio = "fins el"; break;
case "è piena":  				$messaggio = "és plena"; break;
case "è pieno":  				$messaggio = "és ple"; break;
case "<b>C'è</b> ancora disponibilità nel periodo richiesto":	$messaggio = "Encara <b>hi ha</b> disponibilitat pel període demanat"; break;
case ", ma si dovranno fare degli spostamenti nei periodi della <div style=\"display: inline; color: blue;\">regola di assegnazione 1</div>":	$messaggio = ", perà caldrà fer alguns movimients als períodes de la <div style=\"display: inline; color: blue;\">regla d'assignació 1</div>"; break;
case "<b>Non c'è</b> più disponibilità nel periodo richiesto":	$messaggio = "<b>No hi ha</b> disponibilitat al període demanat"; break;
case "Si potrebbe inserire la prenotazione dividendola in":	$messaggio = "Se podria inserir la reserva dividint-la en"; break;
case "parti":  					$messaggio = "trams"; break;
case "Periodo di":  				$messaggio = "Període de"; break;
case "dal":  					$messaggio = "des del"; break;
case "settimane":  				$messaggio = "setmanes"; break;
case "giorni":  				$messaggio = "dies"; break;
case "Tariffa":  				$messaggio = "Tarifa"; break;
case "compresi":  				$messaggio = "inclosos"; break;
case "di costi aggiuntivi fissi":  		$messaggio = "de suplements fixes"; break;
case "Ricontrolla":  				$messaggio = "Torna a cercar"; break;
case "Torna al menù principale":  		$messaggio = "Torna al menú principal"; break;
case "documento di tipo":  			$messaggio = "document tipus"; break;
case "visualizza":  				$messaggio = "Veure"; break;
case "con la tariffa":  			$messaggio = "amb la tarifa"; break;
case "Inserisci la prenotazione":  		$messaggio = "Insereix la reserva"; break;
case "settimana":  				$messaggio = "setmana"; break;
case "giorno":  				$messaggio = "dia"; break;
case "Non c'è nussun periodo delle regole 1 in cui sia consentito inserire prenotazioni per l'utente":	$messaggio = "No hi ha cap període de les regles 1 al qual s'hi permeti inserir reserves a l'usuari"; break;
case "costo aggiuntivo unico":  		$messaggio = "suplement puntual"; break;
case "costo aggiuntivo settimanale":  		$messaggio = "suplement setmanal"; break;
case "costo aggiuntivo giornaliero":  		$messaggio = "suplement diari"; break;
case "nº di settimane da applicare":  		$messaggio = "nº de setmanes a aplicar"; break;
case "nº di giorni da applicare":  		$messaggio = "nº de dies a aplicar"; break;
case "di costi aggiuntivi":  			$messaggio = "de suplements"; break;
case "Aggiungi":  				$messaggio = "Afegir"; break;
case "da moltiplicare per":  			$messaggio = "a multiplicar per"; break;
case "Non si sono potuti applicare alla tariffa uno o più costi":	$messaggio = "No s'han pogut aplicar un o més costos a la tarifa"; break;
case "Scegliere le settimane in cui applicare il costo aggiuntivo":	$messaggio = "Escollir les setmanes a les quals s'aplicarà el suplement"; break;
case "Continua":  				$messaggio = "Continua"; break;
case "tariffa":  				$messaggio = "tarifa"; break;
case "Quadro indicativo disponibilità":  	$messaggio = "Quadre de disponibilitat"; break;
case "potrebbe non essere preciso":  		$messaggio = "podria no ser exacte"; break;
case "persona":  				$messaggio = "persona"; break;
case "Caparra":  				$messaggio = "Arres"; break;
case "con i costi aggiuntivi selezionati":  	$messaggio = "amb els suplements seleccionats"; break;
case "per":  					$messaggio = "per"; break;
case "Commissioni":  				$messaggio = "Comissions"; break;
case "Non c'è nessuna tariffa disponibile in questo periodo":	$messaggio = "No hi ha cap tarifa disponible a aquest període"; break;
case "Mostra le tariffe non disponibili":  	$messaggio = "Mostrar tarifes no disponibles"; break;
case "Scegliere le settimane in cui applicare il costo aggiuntivo":	$messaggio = "Escollir les semanes a les quals s'aplicarà el suplement"; break;
case "Scegliere i giorni in cui applicare il costo aggiuntivo":	$messaggio = "Escollir els dies als quals s'aplicarà el suplement"; break;
case "costo aggiuntivo":  			$messaggio = "suplement"; break;
case "Disponibilità":  				$messaggio = "Availability"; break;
case "TOTALE":  				$messaggio = "TOTAL"; break;
case "non disponibile":  			$messaggio = "not available"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
